@@ -13,8 +13,9 @@ return (new PhpCsFixer\Config())
         'heredoc_to_nowdoc' => false,
         'ordered_imports' => true,
         'phpdoc_types_order' => ['null_adjustment' => 'always_last', 'sort_algorithm' => 'none'],
-        'native_function_invocation' => ['include' => ['@compiler_optimized'], 'scope' => 'all'],
-    ])
+        // TODO: Remove once the "compiler_optimized" set includes "sprintf"
+        'native_function_invocation' => ['include' => ['@compiler_optimized', 'sprintf'], 'scope' => 'all'],
+        ])
     ->setRiskyAllowed(true)
     ->setFinder((new PhpCsFixer\Finder())->in(__DIR__))
 ;
