@@ -65,7 +65,7 @@ class FunctionalTest extends TestCase
         $twig->render('index');
     }
 
-    private function createEnvironment(array $templates, ArrayAdapter $cache = null): Environment
+    private function createEnvironment(array $templates, ?ArrayAdapter $cache = null): Environment
     {
         $twig = new Environment(new ArrayLoader($templates));
         $cache = $cache ?? new ArrayAdapter();
@@ -78,11 +78,9 @@ class FunctionalTest extends TestCase
                 $this->cache = $cache;
             }
 
-            public function load($class)
+            public function load(string $class): ?object
             {
-                if (CacheRuntime::class === $class) {
-                    return new CacheRuntime($this->cache);
-                }
+                return CacheRuntime::class === $class ? new CacheRuntime($this->cache) : null;
             }
         });
 
