@@ -18,7 +18,7 @@ class LeagueMarkdown implements MarkdownInterface
     private $converter;
     private $legacySupport;
 
-    public function __construct(CommonMarkConverter $converter = null)
+    public function __construct(?CommonMarkConverter $converter = null)
     {
         $this->converter = $converter ?: new CommonMarkConverter();
         $this->legacySupport = !method_exists($this->converter, 'convert');
