@@ -14,15 +14,15 @@ namespace Twig\Tests;
 use PHPUnit\Framework\TestCase;
 use Twig\Compiler;
 use Twig\Environment;
-use Twig\Loader\LoaderInterface;
+use Twig\Loader\ArrayLoader;
 
 class CompilerTest extends TestCase
 {
     public function testReprNumericValueWithLocale()
     {
-        $compiler = new Compiler(new Environment($this->createMock(LoaderInterface::class)));
+        $compiler = new Compiler(new Environment(new ArrayLoader()));
 
-        $locale = setlocale(\LC_NUMERIC, 0);
+        $locale = setlocale(\LC_NUMERIC, '0');
         if (false === $locale) {
             $this->markTestSkipped('Your platform does not support locales.');
         }
@@ -33,7 +33,7 @@ class CompilerTest extends TestCase
         }
 
         $this->assertEquals('1.2', $compiler->repr(1.2)->getSource());
-        $this->assertStringContainsString('fr', strtolower(setlocale(\LC_NUMERIC, 0)));
+        $this->assertStringContainsString('fr', strtolower(setlocale(\LC_NUMERIC, '0')));
 
         setlocale(\LC_NUMERIC, $locale);
     }
