@@ -58,7 +58,7 @@ class CoreTest extends TestCase
     {
         return [
             'empty' => [[]],
-            'non-countable' => [new class() extends \ArrayObject {
+            'non-countable' => [new class extends \ArrayObject {
             }],
         ];
     }
@@ -393,6 +393,11 @@ class CoreTest extends TestCase
         $this->expectException(SecurityError::class);
         $twig->render('index');
     }
+
+    public function testLastModified()
+    {
+        $this->assertGreaterThan(1000000000, (new CoreExtension())->getLastModified());
+    }
 }
 
 final class CoreTestIteratorAggregate implements \IteratorAggregate
