@@ -12,6 +12,7 @@ namespace Twig\Tests;
  */
 
 use Twig\DeprecatedCallableInfo;
+use Twig\Error\SyntaxError;
 use Twig\Extension\AbstractExtension;
 use Twig\Extension\DebugExtension;
 use Twig\Extension\SandboxExtension;
@@ -49,6 +50,32 @@ class IntegrationTest extends IntegrationTestCase
         ];
     }
 
+    protected function getUndefinedFunctionCallbacks(): array
+    {
+        return [
+            static function (string $name) {
+                if ('throwing_undefined_function' === $name) {
+                    throw new SyntaxError('This function is undefined in the tests.');
+                }
+
+                return false;
+            },
+        ];
+    }
+
+    protected function getUndefinedTokenParserCallbacks(): array
+    {
+        return [
+            static function (string $name) {
+                if ('throwing_undefined_filter' === $name) {
+                    throw new SyntaxError('This filter is undefined in the tests.');
+                }
+
+                return false;
+            },
+        ];
+    }
+
     protected static function getFixturesDirectory(): string
     {
         return __DIR__.'/Fixtures/';
