@@ -23,12 +23,12 @@ class BlockReferenceTest extends NodeTestCase
         $this->assertEquals('foo', $node->getAttribute('name'));
     }
 
-    public function getTests()
+    public static function provideTests(): iterable
     {
         return [
-            [new BlockReferenceNode('foo', 1), <<<EOF
+            [new BlockReferenceNode('foo', 1), <<<'EOF'
 // line 1
-\$this->displayBlock('foo', \$context, \$blocks);
+yield from $this->unwrap()->yieldBlock('foo', $context, $blocks);
 EOF
             ],
         ];
