@@ -25,7 +25,7 @@ class SandboxTest extends NodeTestCase
         $this->assertEquals($body, $node->getNode('body'));
     }
 
-    public function getTests()
+    public static function provideTests(): iterable
     {
         $tests = [];
 
@@ -38,7 +38,7 @@ if (!\$alreadySandboxed = \$this->sandbox->isSandboxed()) {
     \$this->sandbox->enableSandbox();
 }
 try {
-    echo "foo";
+    yield "foo";
 } finally {
     if (!\$alreadySandboxed) {
         \$this->sandbox->disableSandbox();
