@@ -13,7 +13,7 @@ namespace Twig\Tests\Profiler\Dumper;
 
 use Twig\Profiler\Dumper\HtmlDumper;
 
-class HtmlTest extends AbstractTest
+class HtmlTest extends ProfilerTestCase
 {
     public function testDump()
     {
@@ -29,6 +29,6 @@ class HtmlTest extends AbstractTest
     └ <span style="background-color: #ffd">included.twig</span>
 </pre>
 EOF
-        , $dumper->dump($this->getProfile()));
+            , $dumper->dump($this->getProfile()));
     }
 }
